@@ -6,8 +6,14 @@ NUM_MAX_COEFFS_DSP = 12
 NUM_DSP_CLASSES = 7
 
 ETH_CMD_REQUEST = b"\x11"
+
 COM_FUNCTION = "\x50"
 COM_WRITE_VAR = "\x20"
+COM_CREATE_BSMP_GROUP = "\x30"
+COM_GET_BSMP_GROUP_LIST = "\x04"
+COM_GET_BSMP_GROUP_VARS = "\x06"
+COM_READ_BSMP_GROUP_VALUES = "\x12"
+
 WRITE_FLOAT_SIZE_PAYLOAD = "\x00\x05"
 WRITE_DOUBLE_SIZE_PAYLOAD = "\x00\x03"
 COM_READ_VAR = "\x10\x00\x01"
