@@ -1,3 +1,4 @@
+"""Communication overload types"""
 import re
 import socket
 import struct
@@ -16,16 +17,11 @@ logger = get_logger(name=__file__)
 class SerialDRS(BaseDRS):
     """DRS communication through serial ports"""
 
-    def __init__(self, port: str = None, baud: int = 115200):
+    def __init__(self, port: str, baud: int = 115200):
         super().__init__()
         self.ser: typing.Optional[serial.Serial] = None
 
-        if port is None:
-            print(
-                "From 2.0.0 onwards, creating the object then using 'connect' to connect will be deprecated. Please use 'SerialDRS(port, baud)' instead."
-            )
-        else:
-            self.connect(port, baud)
+        self.connect(port, baud)
 
     def _transfer_write(self, msg: str):
         full_msg = (self._slave_addr + msg).encode("ISO-8859-1")
@@ -36,7 +32,7 @@ class SerialDRS(BaseDRS):
         self._transfer_write(msg)
         return self.ser.read(size)
 
-    def _reset_input_buffer(self):
+    def reset_input_buffer(self):
         self.ser.reset_input_buffer()
 
     @property
@@ -82,21 +78,16 @@ class SerialDRS(BaseDRS):
 class EthDRS(BaseDRS):
     """DRS communication through TCP/IP"""
 
-    def __init__(self, address: str = None, port: int = 5000):
+    def __init__(self, address: str, port: int = 5000):
         super().__init__()
         self._serial_timeout = 50
-        if address is None:
-            print(
-                "From 2.0.0 onwards, creating the object then using 'connect' to connect will be deprecated. Please use 'EthDRS(address, port)' instead."
-            )
-        else:
-            self.connect(address, port)
+        self.connect(address, port)
 
     def _format_message(self, msg: bytes, msg_type: bytes) -> bytes:
         msg = msg_type + struct.Struct(">f").pack(self._serial_timeout) + msg
         return msg[0:1] + struct.pack(">I", (len(msg) - 1)) + msg[1:]
 
-    def _reset_input_buffer(self):
+    def reset_input_buffer(self):
         self.socket.sendall(ETH_RESET_CMD)
         self.socket.recv(16)
 
@@ -104,7 +95,7 @@ class EthDRS(BaseDRS):
     def _parse_reply_size(reply: bytes) -> int:
         return struct.unpack(">I", reply[1:])[0]
 
-    def _get_reply(self, size: int = None) -> bytes:
+    def _get_reply(self, _: int = None) -> bytes:
         data_size = self._parse_reply_size(self.socket.recv(5))
         payload = b""
 
@@ -117,7 +108,7 @@ class EthDRS(BaseDRS):
             if payload[0] == ETH_ANSWER_ERR:
                 raise TimeoutError("Server timed out waiting for serial response")
         except IndexError:
-            self._reset_input_buffer()
+            self.reset_input_buffer()
             raise SerialErrPckgLen(
                 "Received empty response, check if the controller is on and connected. If you receive garbled output, try disconnecting and reconnecting."
             )
@@ -135,11 +126,11 @@ class EthDRS(BaseDRS):
         base_msg = (self._slave_addr + msg).encode("ISO-8859-1")
         full_msg = self._format_message(checksum(base_msg), ETH_CMD_REQUEST)
         self.socket.sendall(full_msg)
-        try: 
+        try:
             self._get_reply()
             return
-        except:
-            return
+        except SerialErrPckgLen:
+            pass
 
     @property
     def timeout(self) -> float:
@@ -151,19 +142,11 @@ class EthDRS(BaseDRS):
         self.socket.settimeout(new_timeout)
 
     def is_open(self) -> bool:
-        try:
-            data = self.socket.recv(4, socket.MSG_DONTWAIT | socket.MSG_PEEK)
-            if len(data) == 0:
-                return False
-        except BlockingIOError:
-            return True
-        except ConnectionResetError:
-            return False
-        return True
+        raise NotImplementedError
 
     def connect(self, address: str = "127.0.0.1", port: int = 5000):
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        self.socket.settimeout(2)
+        self.socket.settimeout(5)
 
         self.socket.connect((address, port))
         self.socket.setsockopt(socket.SOL_TCP, socket.TCP_NODELAY, 1)
@@ -176,5 +159,5 @@ def GenericDRS(com_or_address: str, port_or_baud: int):
     """Factory for DRS communication classes"""
     if re.match(r"(([0-9]{1,3}\.){3}[0-9]{1,3})", com_or_address):
         return EthDRS(com_or_address, port_or_baud)
-    else:
-        return SerialDRS(com_or_address, port_or_baud)
+
+    return SerialDRS(com_or_address, port_or_baud)
