@@ -1,8 +1,6 @@
-from warnings import warn
+"""Handles received message validation"""
 from .consts import ETH_ANSWER_NOQUEUE
 
-from .utils import checksum
-
 
 class SerialError(Exception):
     """Exception raised when there's a problem with serial."""
@@ -49,35 +47,35 @@ ERROR_RESPONSE = {
 
 
 def validate(func):
+    """Validates message and raises errors if invalid. In case given size is 0, any size is accepted."""
+
     def wrapper(*args, **kwargs):
         reply = func(*args, **kwargs)
         if len(reply) == 0 or (len(reply) == 1 and reply[0] == ETH_ANSWER_NOQUEUE):
-            args[0]._reset_input_buffer()
+            args[0].reset_input_buffer()
             raise SerialErrPckgLen(
                 "Received empty response, check if the controller is on and connected. If you receive garbled output, try disconnecting and reconnecting."
             )
 
-        reply = reply[1:] if len(reply) - 1 == args[2] else reply
+        reply = reply[1:] if len(reply) - 1 == args[2] or not args[2] else reply
         check_serial_error(reply)
 
-        if len(reply) != args[2] or (len(reply) - 1 != args[2] and reply[0] == 0x21):
+        if args[2] and (
+            len(reply) != args[2] or (len(reply) - 1 != args[2] and reply[0] == 0x21)
+        ):
             offset = 1 if reply[0] == 0x21 else 0
             if len(reply) > 5:
                 check_serial_error(reply[offset:])
 
-            args[0]._reset_input_buffer()
+            args[0].reset_input_buffer()
             raise SerialErrPckgLen(
-                "Expected {} bytes, received {} bytes".format(
-                    args[2], len(reply) - offset
-                )
+                f"Expected {args[2]} bytes, received {len(reply) - offset} bytes"
             )
 
-        if reply != checksum(reply[:-1]):
-            args[0]._reset_input_buffer()
+        if sum(reply) % 256 != 0:
+            args[0].reset_input_buffer()
             raise SerialErrCheckSum(
-                "Expected {} as checksum, received {}".format(
-                    checksum(reply[:-1])[-1], reply[-1]
-                )
+                f"Expected {256 - sum(reply[2:-1])%256} as checksum, received {reply[-1]}"
             )
 
         return reply
@@ -87,9 +85,9 @@ def validate(func):
 
 def print_deprecated(func):
     def wrapper(*args, **kwargs):
-        warn(
+        """warn(
             "From 2.0.0, most functions will not loop implicitly. Use a 'for' or 'while' loop instead"
-        )
+        )"""
         return func(*args, **kwargs)
 
     return wrapper
@@ -104,7 +102,7 @@ def check_serial_error(reply: bytes):
             )
         if reply[-2] == 8:
             raise SerialInvalidCmd
-        else:
-            raise SerialError(SERIAL_ERROR[reply[-2]])
-    elif reply[error_index] in ERROR_RESPONSE:
+        raise SerialError(SERIAL_ERROR[reply[-2]])
+
+    if reply[error_index] in ERROR_RESPONSE:
         raise SerialInvalidCmd(ERROR_RESPONSE[reply[error_index]])
